audmetric
=========

.. automodule:: audmetric

accuracy
--------

.. autofunction:: accuracy

concordance_cc
--------------

.. autofunction:: concordance_cc


confusion_matrix
----------------

.. autofunction:: confusion_matrix

detection_error_tradeoff
------------------------

.. autofunction:: detection_error_tradeoff

edit_distance
-------------

.. autofunction:: edit_distance

equal_error_rate
----------------

.. autofunction:: equal_error_rate

event_error_rate
----------------

.. autofunction:: event_error_rate

mean_absolute_error
-------------------

.. autofunction:: mean_absolute_error

mean_squared_error
------------------

.. autofunction:: mean_squared_error

pearson_cc
----------

.. autofunction:: pearson_cc

fscore_per_class
----------------

.. autofunction:: fscore_per_class

precision_per_class
-------------------

.. autofunction:: precision_per_class

recall_per_class
----------------

.. autofunction:: recall_per_class

unweighted_average_bias
-----------------------

.. autofunction:: unweighted_average_bias

unweighted_average_fscore
-------------------------

.. autofunction:: unweighted_average_fscore

unweighted_average_precision
----------------------------

.. autofunction:: unweighted_average_precision

unweighted_average_recall
-------------------------

.. autofunction:: unweighted_average_recall

weighted_confusion_error
------------------------

.. autofunction:: weighted_confusion_error

word_error_rate
---------------

.. autofunction:: word_error_rate
